@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 The :class:`.TableSet` class collects a set of related tables in a single data
 structure. The most common way of creating a :class:`.TableSet` is using the
@@ -24,8 +22,8 @@ and end up with data grouped across multiple dimensions.
 dimensions.
 """
 
-import six
-from six.moves import zip_longest
+from io import StringIO
+from itertools import zip_longest
 
 from agate.data_types import Text
 from agate.mapped_sequence import MappedSequence
@@ -86,7 +84,7 @@ class TableSet(MappedSequence):
         """
         Print the tableset's structure via :meth:`TableSet.print_structure`.
         """
-        structure = six.StringIO()
+        structure = StringIO()
 
         self.print_structure(output=structure)
 
