@@ -1,10 +1,5 @@
-#!/usr/bin/env python
-# pylint: disable=W0212
-
 import leather
 
-from agate import utils
-
 
 def bar_chart(self, label=0, value=1, path=None, width=None, height=None):
     """
