@@ -1,24 +1,14 @@
-#!/usr/bin/env python
-# -*- coding: utf8 -*-
-
+import unittest
 from random import shuffle
 from timeit import Timer
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
-import six
-from six.moves import range
-
 import agate
 
 
 class TestTableJoin(unittest.TestCase):
     def test_join(self):
-        left_rows = [(six.text_type(i), i) for i in range(100000)]
-        right_rows = [(six.text_type(i), i) for i in range(100000)]
+        left_rows = [(str(i), i) for i in range(100000)]
+        right_rows = [(str(i), i) for i in range(100000)]
 
         shuffle(left_rows)
         shuffle(right_rows)
@@ -36,4 +26,4 @@ class TestTableJoin(unittest.TestCase):
 
         min_time = min(results)
 
-        self.assertLess(min_time, 10)  # CI unreliable, 5s witnessed
+        self.assertLess(min_time, 20)  # CI unreliable, 15s witnessed on PyPy
