@@ -1,16 +1,9 @@
-#!/usr/bin/env python
-# -*- coding: utf8 -*-
-
 import datetime
 import sys
+import unittest
 import warnings
 from decimal import Decimal
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
 from agate import Table
 from agate.aggregations import (IQR, MAD, All, Any, Count, Deciles, First, HasNulls, Max, MaxLength, MaxPrecision,
                                 Mean, Median, Min, Mode, Percentiles, PopulationStDev, PopulationVariance, Quartiles,
@@ -191,11 +184,13 @@ class TestDateTimeAggregation(unittest.TestCase):
         self.table = Table(self.rows, ['test', 'null'], [DateTime(), DateTime()])
 
         self.time_delta_rows = [
-            [datetime.timedelta(seconds=10), None],
-            [datetime.timedelta(seconds=20), None],
+            [datetime.timedelta(seconds=10), datetime.timedelta(seconds=15), None],
+            [datetime.timedelta(seconds=20), None, None],
         ]
 
-        self.time_delta_table = Table(self.time_delta_rows, ['test', 'null'], [TimeDelta(), TimeDelta()])
+        self.time_delta_table = Table(
+            self.time_delta_rows, ['test', 'mixed', 'null'], [TimeDelta(), TimeDelta(), TimeDelta()]
+        )
 
     def test_min(self):
         self.assertIsInstance(Min('test').get_aggregate_data_type(self.table), DateTime)
@@ -223,6 +218,27 @@ class TestDateTimeAggregation(unittest.TestCase):
         Max('test').validate(self.time_delta_table)
         self.assertEqual(Max('test').run(self.time_delta_table), datetime.timedelta(0, 20))
 
+    def test_mean(self):
+        with self.assertWarns(NullCalculationWarning):
+            Mean('mixed').validate(self.time_delta_table)
+
+        Mean('test').validate(self.time_delta_table)
+
+        self.assertEqual(Mean('test').run(self.time_delta_table), datetime.timedelta(seconds=15))
+
+    def test_mean_all_nulls(self):
+        self.assertIsNone(Mean('null').run(self.time_delta_table))
+
+    def test_mean_with_nulls(self):
+        warnings.simplefilter('ignore')
+
+        try:
+            Mean('mixed').validate(self.time_delta_table)
+        finally:
+            warnings.resetwarnings()
+
+        self.assertAlmostEqual(Mean('mixed').run(self.time_delta_table), datetime.timedelta(seconds=15))
+
     def test_sum(self):
         self.assertIsInstance(Sum('test').get_aggregate_data_type(self.time_delta_table), TimeDelta)
         Sum('test').validate(self.time_delta_table)
@@ -777,7 +793,7 @@ class TestTextAggregation(unittest.TestCase):
         """
         rows = [
             ['a'],
-            [u'👍'],
+            ['👍'],
             ['w']
         ]
 
