@@ -188,6 +188,19 @@ class TestNumber(unittest.TestCase):
         with self.assertRaises(CastError):
             self.type.cast('quack')
 
+    def test_cast_error_leading_zeroes(self):
+        data_type = Number(no_leading_zeroes=True)
+
+        self.assertEqual(data_type.cast('0'), Decimal('0'))
+        self.assertEqual(data_type.cast('0.123'), Decimal('0.123'))
+        self.assertEqual(data_type.cast('123'), Decimal('123'))
+
+        with self.assertRaises(CastError):
+            data_type.cast('01')
+
+        with self.assertRaises(CastError):
+            data_type.cast('00.11')
+
 
 class TestDate(unittest.TestCase):
     def setUp(self):
@@ -263,9 +276,15 @@ class TestDate(unittest.TestCase):
         date_type = Date(date_format='%d-%b-%Y', locale='de_DE.UTF-8')
 
         # March can be abbreviated to Mrz or Mär depending on the locale version,
-        # so we use December in the first value to ensure the test passes everywhere
-        values = ('01-Dez-1994', '17-Feb-2011', None, '05-Jan-1984', 'n/a')
-        casted = tuple(date_type.cast(v) for v in values)
+        # so we use December in the first value to ensure the test passes everywhere.
+        # NetBSD has a different locale database than glibc.
+        try:
+            values = ('01-Dez-1994', '17-Feb-2011', None, '05-Jan-1984', 'n/a')
+            casted = tuple(date_type.cast(v) for v in values)
+        except CastError:
+            values = ('01-Dez.-1994', '17-Feb.-2011', None, '05-Jan.-1984', 'n/a')
+            casted = tuple(date_type.cast(v) for v in values)
+
         self.assertSequenceEqual(casted, (
             datetime.date(1994, 12, 1),
             datetime.date(2011, 2, 17),
