@@ -1,14 +1,5 @@
-#!/usr/bin/env python
-# -*- coding: utf8 -*-
-
-try:
-    from cdecimal import Decimal
-except ImportError:  # pragma: no cover
-    from decimal import Decimal
-
 import warnings
-
-import six
+from decimal import Decimal
 
 from agate import Table
 from agate.computations import Formula
@@ -23,7 +14,7 @@ class TestBasic(AgateTestCase):
         self.rows = (
             (1, 4, 'a'),
             (2, 3, 'b'),
-            (None, 2, u'👍')
+            (None, 2, '👍')
         )
 
         self.number_type = Number()
@@ -75,7 +66,7 @@ class TestBasic(AgateTestCase):
         self.assertRows(table, [
             (1, '4', 'a'),
             (2, '3', 'b'),
-            (None, '2', u'👍')
+            (None, '2', '👍')
         ])
 
     def test_create_table_column_types_dict(self):
@@ -232,8 +223,8 @@ class TestBasic(AgateTestCase):
         with self.assertRaises(KeyError):
             table.columns['one']
 
-        self.assertSequenceEqual(table.columns[2], ('a', 'b', u'👍'))
-        self.assertSequenceEqual(table.columns['c'], ('a', 'b', u'👍'))
+        self.assertSequenceEqual(table.columns[2], ('a', 'b', '👍'))
+        self.assertSequenceEqual(table.columns['c'], ('a', 'b', '👍'))
 
         with self.assertRaises(KeyError):
             table.columns['']
@@ -258,7 +249,7 @@ class TestBasic(AgateTestCase):
     def test_row_names(self):
         table = Table(self.rows, self.column_names, self.column_types, row_names='three')
 
-        self.assertRowNames(table, ['a', 'b', u'👍'])
+        self.assertRowNames(table, ['a', 'b', '👍'])
 
     def test_row_names_non_string(self):
         table = Table(self.rows, self.column_names, self.column_types, row_names=[Decimal('2'), True, None])
@@ -270,7 +261,7 @@ class TestBasic(AgateTestCase):
         ])
         self.assertSequenceEqual(table.rows[Decimal('2')], (1, 4, 'a'))
         self.assertSequenceEqual(table.rows[True], (2, 3, 'b'))
-        self.assertSequenceEqual(table.rows[None], (None, 2, u'👍'))
+        self.assertSequenceEqual(table.rows[None], (None, 2, '👍'))
 
     def test_row_names_int(self):
         with self.assertRaises(ValueError):
@@ -282,11 +273,11 @@ class TestBasic(AgateTestCase):
         self.assertSequenceEqual(table.row_names, [
             (Decimal('1'), 'a'),
             (Decimal('2'), 'b'),
-            (None, u'👍')
+            (None, '👍')
         ])
         self.assertSequenceEqual(table.rows[(Decimal('1'), 'a')], (1, 4, 'a'))
         self.assertSequenceEqual(table.rows[(Decimal('2'), 'b')], (2, 3, 'b'))
-        self.assertSequenceEqual(table.rows[(None, u'👍')], (None, 2, u'👍'))
+        self.assertSequenceEqual(table.rows[(None, '👍')], (None, 2, '👍'))
 
     def test_row_names_invalid(self):
 
@@ -299,28 +290,15 @@ class TestBasic(AgateTestCase):
             )
 
     def test_stringify(self):
-        column_names = ['foo', 'bar', u'👍']
+        column_names = ['foo', 'bar', '👍']
 
         table = Table(self.rows, column_names)
 
-        if six.PY2:
-            u = unicode(table)  # noqa: F821
+        u = str(table)
 
-            self.assertIn('foo', u)
-            self.assertIn('bar', u)
-            self.assertIn(u'👍', u)
-
-            s = str(table)
-
-            self.assertIn('foo', s)
-            self.assertIn('bar', s)
-            self.assertIn(u'👍'.encode('utf-8'), s)
-        else:
-            u = str(table)
-
-            self.assertIn('foo', u)
-            self.assertIn('bar', u)
-            self.assertIn(u'👍', u)
+        self.assertIn('foo', u)
+        self.assertIn('bar', u)
+        self.assertIn('👍', u)
 
     def test_str(self):
         warnings.simplefilter('ignore')
@@ -379,7 +357,7 @@ class TestBasic(AgateTestCase):
         self.assertRows(new_table, [
             [4, 'a'],
             [3, 'b'],
-            [2, u'👍']
+            [2, '👍']
         ])
 
     def test_select_single(self):
@@ -391,14 +369,14 @@ class TestBasic(AgateTestCase):
         self.assertRows(new_table, [
             ['a'],
             ['b'],
-            [u'👍']
+            ['👍']
         ])
 
     def test_select_with_row_names(self):
         table = Table(self.rows, self.column_names, self.column_types, row_names='three')
         new_table = table.select(('three',))
 
-        self.assertRowNames(new_table, ['a', 'b', u'👍'])
+        self.assertRowNames(new_table, ['a', 'b', '👍'])
 
     def test_select_does_not_exist(self):
         table = Table(self.rows, self.column_names, self.column_types)
@@ -418,7 +396,7 @@ class TestBasic(AgateTestCase):
         self.assertRows(new_table, [
             ['a'],
             ['b'],
-            [u'👍']
+            ['👍']
         ])
 
     def test_exclude_single(self):
@@ -433,14 +411,14 @@ class TestBasic(AgateTestCase):
         self.assertRows(new_table, [
             [4, 'a'],
             [3, 'b'],
-            [2, u'👍']
+            [2, '👍']
         ])
 
     def test_exclude_with_row_names(self):
         table = Table(self.rows, self.column_names, self.column_types, row_names='three')
         new_table = table.exclude(('one', 'two'))
 
-        self.assertRowNames(new_table, ['a', 'b', u'👍'])
+        self.assertRowNames(new_table, ['a', 'b', '👍'])
 
     def test_where(self):
         table = Table(self.rows, self.column_names, self.column_types)
@@ -460,7 +438,7 @@ class TestBasic(AgateTestCase):
         table = Table(self.rows, self.column_names, self.column_types, row_names='three')
         new_table = table.where(lambda r: r['one'] in (2, None))
 
-        self.assertRowNames(new_table, ['b', u'👍'])
+        self.assertRowNames(new_table, ['b', '👍'])
 
     def test_find(self):
         table = Table(self.rows, self.column_names, self.column_types)
