@@ -1,7 +1,5 @@
-#!/usr/bin/env python
-# -*- coding: utf8 -*-
+from io import StringIO
 
-import six
 from babel.numbers import get_decimal_symbol
 
 from agate import Table
@@ -33,7 +31,7 @@ class TestPrintTable(AgateTestCase):
     def test_print_table(self):
         table = Table(self.rows, self.column_names, self.column_types)
 
-        output = six.StringIO()
+        output = StringIO()
         table.print_table(output=output)
         lines = output.getvalue().split('\n')
 
@@ -43,7 +41,7 @@ class TestPrintTable(AgateTestCase):
     def test_print_table_max_rows(self):
         table = Table(self.rows, self.column_names, self.column_types)
 
-        output = six.StringIO()
+        output = StringIO()
         table.print_table(max_rows=2, output=output)
         lines = output.getvalue().split('\n')
 
@@ -53,7 +51,7 @@ class TestPrintTable(AgateTestCase):
     def test_print_table_max_columns(self):
         table = Table(self.rows, self.column_names, self.column_types)
 
-        output = six.StringIO()
+        output = StringIO()
         table.print_table(max_columns=2, output=output)
         lines = output.getvalue().split('\n')
 
@@ -75,22 +73,22 @@ class TestPrintTable(AgateTestCase):
         ]
         table = Table(rows, column_names, column_types)
 
-        output = six.StringIO()
+        output = StringIO()
         table.print_table(output=output, max_precision=2)
         lines = output.getvalue().split('\n')
 
         # Text shouldn't be affected
-        self.assertIn(u' 1.745 ', lines[2])
-        self.assertIn(u' 11.123456 ', lines[3])
-        self.assertIn(u' 0 ', lines[4])
+        self.assertIn(' 1.745 ', lines[2])
+        self.assertIn(' 11.123456 ', lines[3])
+        self.assertIn(' 0 ', lines[4])
         # Test real precision above max
-        self.assertIn(u' 1' + get_decimal_symbol() + u'74… ', lines[2])
-        self.assertIn(u' 11' + get_decimal_symbol() + u'12… ', lines[3])
-        self.assertIn(u' 0' + get_decimal_symbol() + u'00… ', lines[4])
+        self.assertIn(' 1' + get_decimal_symbol() + '74… ', lines[2])
+        self.assertIn(' 11' + get_decimal_symbol() + '12… ', lines[3])
+        self.assertIn(' 0' + get_decimal_symbol() + '00… ', lines[4])
         # Test real precision below max
-        self.assertIn(u' 1' + get_decimal_symbol() + u'72 ', lines[2])
-        self.assertIn(u' 5' + get_decimal_symbol() + u'10 ', lines[3])
-        self.assertIn(u' 0' + get_decimal_symbol() + u'10 ', lines[4])
+        self.assertIn(' 1' + get_decimal_symbol() + '72 ', lines[2])
+        self.assertIn(' 5' + get_decimal_symbol() + '10 ', lines[3])
+        self.assertIn(' 0' + get_decimal_symbol() + '10 ', lines[4])
 
     def test_print_table_max_column_width(self):
         rows = (
@@ -102,7 +100,7 @@ class TestPrintTable(AgateTestCase):
         column_names = ['one', 'two', 'three', 'also, this is long']
         table = Table(rows, column_names, self.column_types)
 
-        output = six.StringIO()
+        output = StringIO()
         table.print_table(output=output, max_column_width=7)
         lines = output.getvalue().split('\n')
 
@@ -117,7 +115,7 @@ class TestPrintTable(AgateTestCase):
         """
         table = Table(self.rows, self.column_names, self.column_types)
 
-        output = six.StringIO()
+        output = StringIO()
         table.print_table(max_columns=2, output=output, locale='en_US')
         # If it's working, 2000 should appear as the english '2,000'
         self.assertTrue("2,000" in output.getvalue())
@@ -129,7 +127,7 @@ class TestPrintTable(AgateTestCase):
         """
         table = Table(self.rows, self.column_names, self.column_types)
 
-        output = six.StringIO()
+        output = StringIO()
         table.print_table(max_columns=2, output=output, locale='de_DE.UTF-8')
         # If it's working, the english '2,000' should appear as '2.000'
         self.assertTrue("2.000" in output.getvalue())
