@@ -1,11 +1,5 @@
-#!/usr/bin/env python
-
 from collections import OrderedDict
-
-try:
-    from cdecimal import Decimal
-except ImportError:  # pragma: no cover
-    from decimal import Decimal
+from decimal import Decimal
 
 from agate import Table, TableSet
 from agate.aggregations import Count, MaxLength, Mean, Min, Sum
