@@ -1,14 +1,5 @@
-#!/usr/bin/env python
-
-try:
-    from cdecimal import Decimal
-except ImportError:  # pragma: no cover
-    from decimal import Decimal
-
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
+from decimal import Decimal
 
 from agate.utils import Quantiles, letter_name, round_limits
 
